import { Component } from '@angular/core';
import * as wjOdata from '@grapecity/wijmo.odata';
import * as wjGrid from '@grapecity/wijmo.grid';
import * as wjCore from '@grapecity/wijmo';
import * as pdf from '@grapecity/wijmo.pdf';
import * as gridPdf from '@grapecity/wijmo.grid.pdf';
import * as wjGridXlsx from '@grapecity/wijmo.grid.xlsx';

@Component({
  selector: 'app-grid',
  templateUrl: './grid.component.html',
  styleUrls: ['./grid.component.css']
})
export class GridComponent {
  tabsInfo: any[] = [];
  gridInfo: any[] = [];
  autoSizeInfo: any = {
    0: false,
    1: false,
    2: false,
    3: false
  }
  tabPanel: any;
  dataLoadCount = 0;
  //
  constructor() {
    this._initTabsInfo();
  }

  tabInit(tabPanel: any) {
    this.tabPanel = tabPanel;

    tabPanel.selectedIndexChanged.addHandler((s: any, e: any) => {
      let index = s.selectedIndex;
      if (!this.autoSizeInfo[index]) {
        this.gridInfo[index].autoSizeColumns();
        this.autoSizeInfo[index] = true;
        console.log('autosized');
      }
    })
  }

  flexInit(grid: wjGrid.FlexGrid) {
    this.gridInfo.push(grid);
    let cv: any = grid.collectionView;
    cv.loaded.addHandler((s: any, e: any) => {
      grid.autoSizeColumns();
    })
  }
  private _initTabsInfo() {
    let headers = 'Employees,Categories,Products,Customers'.split(','),
      url = 'https://services.odata.org/Northwind/Northwind.svc/';
    this.tabsInfo = [];
    headers.forEach((header) => {
      this.tabsInfo.push({
        header: header,
        data: new wjOdata.ODataCollectionView(url, header, {
          sortOnServer: false,
        }),
      });
    })
  }

  exportPdf() {
    let doc = new pdf.PdfDocument({
      header: {
        declarative: {
          text: '\t&[Page]\\&[Pages]'
        }
      },
      footer: {
        declarative: {
          text: '\t&[Page]\\&[Pages]'
        }
      },
      ended: (sender, args) => pdf.saveBlob(args.blob, 'FlexGrid.pdf')
    });
    //
    let settings = {
      styles: {
        cellStyle: {
          backgroundColor: '#ffffff',
          borderColor: '#c6c6c6'
        },
        altCellStyle: {
          backgroundColor: '#f9f9f9'
        },
        groupCellStyle: {
          backgroundColor: '#dddddd'
        },
        headerCellStyle: {
          backgroundColor: '#eaeaea'
        }
      }
    };
    //
    this.gridInfo.forEach((grid, index) => {
      if (index != 0)
        doc.addPage()
      doc.drawText(this.tabPanel.tabs[index].header.textContent, undefined, undefined, { width: 200 });

      doc.moveDown();
      // to draw FlexGrid to Pdf doc to fit the document width
      gridPdf.FlexGridPdfConverter.draw(grid, doc, doc.width, undefined, settings);
      // doc.moveDown(2);
      //

    })
    doc.end();
  }

  exportXlsx() {
    let workbook: any;
    this.gridInfo.forEach((grid, index) => {
      // get workbook instance for each flexGrid
      let sheetData = wjGridXlsx.FlexGridXlsxConverter.saveAsync(grid, {
        includeColumnHeaders: true,
        includeStyles: false,
      });

      sheetData.sheets[0].name = this.tabPanel.tabs[index].header.textContent;

      // merging all grid into same workbook/ different sheets
      if (workbook) {
        workbook.sheets.push(sheetData.sheets[0]);
      } else {
        workbook = sheetData;
      }
    });

    workbook.saveAsync('FlexGrid.xlsx');
    this.testSuccessful();
  }

  testSuccessful(){}
}
